#
# spec file for package python-physt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-physt
Version:        0.7.4
Release:        1.1
Summary:        Python histogram library
License:        MIT
URL:            https://github.com/janpipek/physt
Source:         https://github.com/janpipek/physt/archive/v%{version}.tar.gz#/physt-%{version}.tar.gz
# PATCH-FIX-UPSTREAM physt-pr116-np2.patch gh#janpipek/physt#116
Patch0:         physt-pr116-np2.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-hypothesis >= 6.96.1
Requires:       python-numpy >= 1.22
Requires:       python-packaging
Requires:       python-typing-extensions
Recommends:     python-dask-array
Recommends:     python-folium
Recommends:     python-matplotlib
Recommends:     python-pandas
Recommends:     python-protobuf
Recommends:     python-uproot
Recommends:     python-vega3
Recommends:     python-xarray
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module dask-array}
BuildRequires:  %{python_module hypothesis >= 6.96.1}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module numpy >= 1.22}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module plotly}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typing-extensions}
# /SECTION
%python_subpackages

%description
P(i/y)thon h(i/y)stograms. Inspired (and based on) numpy.histogram.

The unifies different concepts of histograms as occurring in numpy,
pandas, matplotlib, ROOT, etc. and to create one representation that
can be manipulated with from the data point of view and at the same
time provides integration into IPython notebook and various plotting
options.

%prep
%autosetup -p1 -n physt-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand rm -rf %{buildroot}%{$python_sitelib}/tests/
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# no polars
%pytest --ignore tests/compat/test_polars.py

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/physt
%{python_sitelib}/physt-%{version}.dist-info

%changelog
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.7.4
  * Dependency: allow numpy 1.22 again
- Release 0.7.3
  * Improved: dealing with extremely narrow bin ranges
  * Fixed: mypy and pytest issues
  * Fixed: compatibility with polars 1.0
- Release 0.7.2
  * Improved: stats box in plots
- Release 0.7.1
  * Fixed: Newer polars compatibility, deal with Nones
  * Added: .physt accessors for polars series and dataframes
- Release 0.7.0
  * Added: Support for pola.rs series/dataframes
  * Moved: xarray support as a separate module in physt.compat
  * Removed: physt.special (use physt.special_histograms instead)
  * Added: stats_loc arg to locate stats box in plots
  * Added: Pretty printing with rich library
  * Changed: Moved most configuration to pyproject.toml
  * Improved: Much more testing and edge-case bug fixes
  * Support: Removed Python 3.7 and numpy <1.22, added 3.11
  * Renamed: human binning => pretty binning (with deprecation
    warning)
- Unpin numpy 2: Add physt-pr116-np2.patch gh#janpipek/physt#116
* Mon Jul  8 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add upper bound on numpy of < 2.
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Build PEP517 wheel
- Fix runtime requirements
- Don't test plotly on python <3.10: no longer available
* Thu Feb 16 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.5.3:
  * Changed: Distribution to wheels
  * Changed: Statistics have a special class
  * Changed: Statistics are now computed from all values (more options for
    plot too)
  * Fixed: Sometimes, dtypes were not properly used
  * Added: A lot of typing hints
  * Fixed: asciiplotlib does not exist anymore => don't use it
  * Changed: Added pre-commit
  * Changed: More thorough typing
  * Support: Added Python 3.10, removed Python 3.6 and numpy<1.20
  * Fixed: A few minor bugs
  * Changed: Reworked pandas compatibility (.to_series, .to_dataframe methods)
  * Added: .physt series/dataframe accessors (with h1, h2, histogram methods)
  * Fixed: A lot of RuntimeError's changed to more specific exceptions
  * Fixed: Typing annotations (again) passing mypy validation.
* Fri Apr 23 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.5.0.1:
  * Removed: *args in method definition whenever possible (prefering
    explicit keyword-only arguments)
  * Changed: In multi-dimensional methods arguments:
    + list is treated as different value for each axes
    + tuple is treated as one argument value
  * Changed: Plotly backend does not allow matplotlib mimicking any more.
  * Added: Basic tests for plotting backends
  * Support: Tested against Python 3.6-3.9
  * Fixed: Typing annotations are passing mypy validation.
  * Fixed: A few small bugs
- Do not build for Python 3.6, due to no NumPy.
* Mon Feb 10 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.4.9
  * Changed: version.py controls the version number etc.
  * Bug fixes
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.4.8.3
  * Added: Binning "human" accepts kind="time"
  * - Added: find_human_width and related methods in bin_utils
  * - Fix: No labels and color cycling in scatter plots for collections
* Mon Jan 21 2019 Todd R <toddrme2178@gmail.com>
- Initial version
* Thu Jan 17 2019 Todd R <toddrme2178@gmail.com>
- Initial version
